#
# spec file for package octave-forge-nan
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  nan
Name:           octave-forge-%{octpkg}
Version:        3.7.0
Release:        1.8
Summary:        A statistics and machine learning toolbox
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io/%{octpkg}/index.html
Source0:        https://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildRequires:  libsvm-devel
BuildRequires:  octave-devel >= 3.8.0
Requires:       octave-cli >= 3.8.0

%description
A statistics and machine learning toolbox for data with and w/o missing values.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

# Spurious exec bit
chmod -x %{buildroot}%{_datadir}/octave/packages/nan-%{version}/fishers_exact_test.m

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Fri Jul  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.7.0:
  * minor improvements (kappa, cdfplot, signrank).
* Fri Nov 12 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.6.1:
  * signrank: update computation of p-value according to revised
    references, and validated against R.
  * cdfplot: use histo instead of histo_mex.
* Wed Sep 15 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.6.0:
  * corrplot, knnsearch <NEW>.
* Sat Mar 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.5.3
  * kappa: Youden index (YI), and SSE as return value
  * roc: add maxYI as output value
  * naninsttest: check ttest for NaN handling
* Sun Nov 15 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.5.2:
  * New functions added:
  - gini: Gini index.
  - lmom: L-moments.
  - betapdf, betacdf, betainv: beta distribution functions.
  * Bug fixes:
  - bland-altman: fix ylabel.
  - fix debian bug #964210: test tries to download data.
  - fix #59335: "'load_fisheriris' fails on Windows".
  - fix #59336: "(nan) BIST for `ttest` fails".
* Tue Aug  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.5.0:
  * ttest: support output arguments CI and STATS.
  * fishers_exact_test:
  - Use VPA from symbolic pkg if available.
  - Add unit tests.
  - Improve help.
- Remove exec bits from a file that isn't in executable path.
* Mon Dec  9 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 3.4.5:
  * fishers_exact_test: added <NEW>
  * bug fixes for:
    + #57263: [octave forge] (nan) fails to build on a system
    without libblas (Octave built with OpenBLAS)
    + #57232: [octave forge] (nan) Spelling error in message of
    function str2array
    + #50248: [octave forge] (nan) Spelling error in the help
    string of the train function
    + #57228 "[octave forge] (nan) fails to build with undefined
    references in Octave 5 when LDFLAGS is set"
  * gscatter: fix use of argument "doleg"
  * address "warning: no return statement in function returning non-void"
- Drop fix_missing_return.patch, fixed upstream
* Wed Nov 27 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 3.4.3:
  + Makefile.*
    Add missing copyright/licenses
  + liblinear, libsvm:
    add license from original author
  + roc.m: number of data points limited to about 5000
    add final data point at (1,1).
- Update to version 3.4.0:
  + quadratic classifiers:
    check for positive-definiteness of covariance matrix
    and return no classification (encoded as NaN), if not.
  + mad, meandev:
    make sure source is ascii/utf-8 compliant
- Update to version 3.3.0:
  + detrend: the 2nd output (trend) can be interpolated and should
    not contain NaNs.
  + train_sc: some supported classifiers should not be used
    with the short-cut for two-class problems.
  + xval: report also results w/o crossvaliation
  + ecdf: fix ylim in case data contains missing values.
- Update to version 3.2.3:
  + <NEW> ROC is included. ROC is derived
    from the implementation in "biosig for octave and matlab"
    biosig-code/biosig4matlab/t490_EvaluationCriteria/
    https://sourceforge.net/p/biosig/code/ci/master/tree/biosig4matlab/t490_EvaluationCriteria/
  + <NEW> load_cifar100 load_cifar10 load_mnist:
    loading of various machine-learning databases
  + <NEW> kolmogorov_smirnov:
    Multiple two-sample Kolmogorov-Smirnov test
  + <NEW> kstest2:
    wrapper for kolmogorov_smirnov
  + requires Octave 3.8 or later
  + histo2, histo3:
    bug fix for case when whole column contains NaNs
  + <NEW> inst/signrank.m: add Wilcoxon signred rank test
    Unlike Octave's wilcoxon_test, this works also for
    sample sizes smaller than N=25
  + corrcoef: improve documentation on one-
    and two- pass algorithm
  + histogram functions (histo.m) included
  + upgrade to liblinear 2.2.1
    weightening of samples not supported anymore
  + upgrade to libsvm 3.2.3
    weightening of samples not supported anymore
  + minor changes
- Fix missing return value for non-void function, add
  fix_missing_return.patch
* Wed Aug 23 2017 dmitry_r@opensuse.org
- Update to version 3.1.4
  * Minor changes and fixes, see `news nan` for details
- Drop oblosete:
  * nan-cpp11.patch
  * nan_xpt2d_add_return_for_BE.patch
* Sat Sep 17 2016 dmitry_r@opensuse.org
- Update to version 3.0.3
  * Bug fixes
- Fix build with GCC 4.8
  * nan-cpp11.patch
* Fri Jun 10 2016 dmitry_r@opensuse.org
- Update to version 3.0.1
  * no changelog available
- Drop obsolete
  * nan-openmp.patch
  * nan-gcc.patch
* Tue Apr 12 2016 normand@linux.vnet.ibm.com
- new nan_xpt2d_add_return_for_BE.patch for ppc64 build
* Tue Jul  7 2015 dmitry_r@opensuse.org
- Update to version 2.8.1
  * Bugfix release
* Sat Jun 27 2015 dmitry_r@opensuse.org
- Update to version 2.8.0
  * check for sparse input matrices and convert to full if needed
  * improve accuracy of normcdf (bug #38170)
  * fix compiler issue with __isnan
  * do not display diagnostic messages
* Thu Apr 16 2015 dmitry_r@opensuse.org
- Update to version 2.7.4
  * use libsvm and liblinear of target system, instead of outdated copy
  * fix multi-threaded build (make -j)
  * improve some tests
  * bug fix in nanstd.m
  * minor issues (some compiler warnings are addressed)
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 2.7.1
- Fix build with OpenMP support
  * nan-openmp.patch
- Fix GCC warnings
  * nan-gcc.patch
